@@ -31,6 +31,7 @@ import org.gradle.api.internal.file.DefaultFileOperations;
 import org.gradle.api.internal.file.FileLookup;
 import org.gradle.api.internal.file.FileOperations;
 import org.gradle.api.internal.file.FileResolver;
+import org.gradle.api.internal.file.HasFileOperations;
 import org.gradle.api.internal.file.collections.DirectoryFileTreeFactory;
 import org.gradle.api.internal.initialization.ClassLoaderScope;
 import org.gradle.api.internal.initialization.ScriptHandlerFactory;
@@ -38,26 +39,34 @@ import org.gradle.api.internal.plugins.DefaultObjectConfigurationAction;
 import org.gradle.api.logging.Logger;
 import org.gradle.api.logging.Logging;
 import org.gradle.api.logging.LoggingManager;
+import org.gradle.api.provider.Provider;
+import org.gradle.api.provider.ProviderFactory;
 import org.gradle.api.resources.ResourceHandler;
 import org.gradle.api.tasks.WorkResult;
 import org.gradle.configuration.ScriptPluginFactory;
 import org.gradle.internal.Actions;
+import org.gradle.internal.hash.FileHasher;
+import org.gradle.internal.hash.StreamHasher;
 import org.gradle.internal.reflect.Instantiator;
+import org.gradle.internal.resource.TextResourceLoader;
 import org.gradle.internal.service.ServiceRegistry;
 import org.gradle.process.ExecResult;
 import org.gradle.process.ExecSpec;
 import org.gradle.process.JavaExecSpec;
+import org.gradle.process.internal.ExecFactory;
 import org.gradle.util.ConfigureUtil;
 
 import java.io.File;
 import java.net.URI;
 import java.util.Map;
+import java.util.concurrent.Callable;
 
 public abstract class DefaultScript extends BasicScript {
     private static final Logger LOGGER = Logging.getLogger(Script.class);
 
     private FileOperations fileOperations;
     private ProcessOperations processOperations;
+    private ProviderFactory providerFactory;
     private LoggingManager loggingManager;
 
     public ServiceRegistry __scriptServices;
@@ -69,24 +78,33 @@ public abstract class DefaultScript extends BasicScript {
         loggingManager = services.get(LoggingManager.class);
         Instantiator instantiator = services.get(Instantiator.class);
         FileLookup fileLookup = services.get(FileLookup.class);
+        ExecFactory execFactory = services.get(ExecFactory.class);
         DirectoryFileTreeFactory directoryFileTreeFactory = services.get(DirectoryFileTreeFactory.class);
-        if (target instanceof FileOperations) {
-            fileOperations = (FileOperations) target;
+        StreamHasher streamHasher = services.get(StreamHasher.class);
+        FileHasher fileHasher = services.get(FileHasher.class);
+        TextResourceLoader textResourceLoader = services.get(TextResourceLoader.class);
+        if (target instanceof HasFileOperations) {
+            fileOperations = ((HasFileOperations) target).getFileOperations();
         } else {
             File sourceFile = getScriptSource().getResource().getLocation().getFile();
             if (sourceFile != null) {
-                fileOperations = new DefaultFileOperations(fileLookup.getFileResolver(sourceFile.getParentFile()), null, null, instantiator, fileLookup, directoryFileTreeFactory);
+                fileOperations = new DefaultFileOperations(fileLookup.getFileResolver(sourceFile.getParentFile()), null, null, instantiator, fileLookup, directoryFileTreeFactory, streamHasher, fileHasher, execFactory, textResourceLoader);
             } else {
-                fileOperations = new DefaultFileOperations(fileLookup.getFileResolver(), null, null, instantiator, fileLookup, directoryFileTreeFactory);
+                fileOperations = new DefaultFileOperations(fileLookup.getFileResolver(), null, null, instantiator, fileLookup, directoryFileTreeFactory, streamHasher, fileHasher, execFactory, textResourceLoader);
             }
         }
 
         processOperations = (ProcessOperations) fileOperations;
+        providerFactory = services.get(ProviderFactory.class);
+    }
+
+    public FileResolver getFileResolver() {
+        return fileOperations.getFileResolver();
     }
 
     @Override
-    public FileResolver getFileResolver() {
-        return fileOperations.getFileResolver();
+    public FileOperations getFileOperations() {
+        return fileOperations;
     }
 
     private DefaultObjectConfigurationAction createObjectConfigurationAction() {
@@ -96,6 +114,7 @@ public abstract class DefaultScript extends BasicScript {
             __scriptServices.get(ScriptPluginFactory.class),
             __scriptServices.get(ScriptHandlerFactory.class),
             classLoaderScope,
+            __scriptServices.get(TextResourceLoader.class),
             getScriptTarget()
         );
     }
@@ -141,12 +160,12 @@ public abstract class DefaultScript extends BasicScript {
 
     @Override
     public ConfigurableFileCollection files(Object... paths) {
-        return fileOperations.files(paths);
+        return fileOperations.configurableFiles(paths);
     }
 
     @Override
     public ConfigurableFileCollection files(Object paths, Closure configureClosure) {
-        return ConfigureUtil.configure(configureClosure, fileOperations.files(paths));
+        return ConfigureUtil.configure(configureClosure, fileOperations.configurableFiles(paths));
     }
 
     @Override
@@ -189,12 +208,10 @@ public abstract class DefaultScript extends BasicScript {
         return copy(ConfigureUtil.configureUsing(closure));
     }
 
-    @Override
     public WorkResult copy(Action<? super CopySpec> action) {
         return fileOperations.copy(action);
     }
 
-    @Override
     public WorkResult sync(Action<? super CopySpec> action) {
         return fileOperations.sync(action);
     }
@@ -204,7 +221,6 @@ public abstract class DefaultScript extends BasicScript {
         return Actions.with(copySpec(), ConfigureUtil.configureUsing(closure));
     }
 
-    @Override
     public CopySpec copySpec() {
         return fileOperations.copySpec();
     }
@@ -219,7 +235,6 @@ public abstract class DefaultScript extends BasicScript {
         return fileOperations.delete(paths);
     }
 
-    @Override
     public WorkResult delete(Action<? super DeleteSpec> action) {
         return fileOperations.delete(action);
     }
@@ -244,6 +259,11 @@ public abstract class DefaultScript extends BasicScript {
         return processOperations.exec(action);
     }
 
+    @Override
+    public <T> Provider<T> provider(Callable<T> value) {
+        return providerFactory.provider(value);
+    }
+
     @Override
     public LoggingManager getLogging() {
         return loggingManager;
